@@ -176,7 +176,7 @@ class PdPipelineStage(abc.ABC):
 
     _DEF_EXC_MSG = 'Precondition failed in stage {}!'
     _DEF_DESCRIPTION = 'A pipeline stage.'
-    _INIT_KWARGS = ['exraise', 'exmsg', 'desc']
+    _INIT_KWARGS = ['exraise', 'exmsg', 'desc', 'prec', 'skip']
 
     def __init__(self, exraise=True, exmsg=None, desc=None, prec=None,
                  skip=None):
@@ -398,6 +398,7 @@ class PdPipelineStage(abc.ABC):
         return self._desc
 
     def _mem_str(self):
+        total = asizeof(self)
         lines = []
         for a in dir(self):
             if not a.startswith('__'):
@@ -405,13 +406,14 @@ class PdPipelineStage(abc.ABC):
                 if not callable(att):
                     size = asizeof(att)
                     if size > 500000:  # pragma: no cover
-                        lines.append('  - {}, {:.2f}Mb\n'.format(
-                            a, size / 1000000))
+                        lines.append('  - {}, {:.2f}Mb ({:0>5.2f}%)\n'.format(
+                            a, size / 1000000, 100 * size / total))
                     elif size > 1000:  # pragma: no cover
-                        lines.append('  - {}, {:.2f}Kb\n'.format(
-                            a, size / 1000))
+                        lines.append('  - {}, {:.2f}Kb ({:0>5.2f}%)\n'.format(
+                            a, size / 1000, 100 * size / total))
                     else:
-                        lines.append('  - {}, {}b\n'.format(a, size))
+                        lines.append('  - {}, {}b ({:0>5.2f}%)\n'.format(
+                            a, size, 100 * size / total))
         return ''.join(lines)
 
 
@@ -572,23 +574,40 @@ class AdHocStage(PdPipelineStage):
     Parameters
     ----------
     transform : callable
-        The transformation this stage applies to dataframes.
+        The transformation this stage applies to dataframes. If the
+        fit_transform parameter is also populated than this transformation is
+        only applied on calls to transform.
+    fit_transform : callable, optional
+        The transformation this stage applies to dataframes, only on
+        fit_transform. Optional.
     prec : callable, default None
         A callable that returns a boolean value. Represent a a precondition
         used to determine whether this stage can be applied to a given
         dataframe. If None is given, set to a function always returning True.
     """
 
-    def __init__(self, transform, prec=None, **kwargs):
+    def __init__(self, transform, fit_transform=None, prec=None, **kwargs):
         if prec is None:
             prec = _always_true
         self._adhoc_transform = transform
+        self._adhoc_fit_transform = fit_transform
         self._adhoc_prec = prec
         super().__init__(**kwargs)
 
     def _prec(self, df):
         return self._adhoc_prec(df)
 
+    def _fit_transform(self, df, verbose):
+        self.is_fitted = True
+        if self._adhoc_fit_transform is None:
+            self.is_fitted = True
+            return self._transform(df, verbose=verbose)
+        try:
+            print("Blah!")
+            return self._adhoc_fit_transform(df, verbose=verbose)
+        except TypeError:
+            return self._adhoc_fit_transform(df)
+
     def _transform(self, df, verbose):
         try:
             return self._adhoc_transform(df, verbose=verbose)
@@ -834,9 +853,9 @@ class PdPipeline(PdPipelineStage, collections.abc.Sequence):
     def __times_str__(self, times):
         res = "A pdpipe pipeline:\n"
         stime = sum(times)
-        if stime > 0:
+        if stime > 0:  # pragma: no cover
             percentages = [100 * x / stime for x in times]
-        else:
+        else:  # pragma: no cover
             percentages = [0 for x in times]
         res += '[ 0] [{:0>5.2f}s ({:0>5.2f}%)]  '.format(
             times[0], percentages[0]
@@ -860,19 +879,21 @@ class PdPipeline(PdPipelineStage, collections.abc.Sequence):
                 textwrap.wrap(stage.description())) + '\n'
         return res
 
-    def _mem_str(self):
+    def _mem_str(self, total):
+        total = asizeof(self)
         lines = []
         for i, stage in enumerate(self._stages):
             size = asizeof(stage)
             if size > 500000:  # pragma: no cover
-                lines.append('[{:>2}] {:.2f}Mb, {}\n'.format(
-                    i, size / 1000000, stage.description()))
+                lines.append('[{:>2}] {:.2f}Mb ({:0>5.2f}%), {}\n'.format(
+                    i, size / 1000000, 100 * size / total,
+                    stage.description()))
             elif size > 1000:  # pragma: no cover
-                lines.append('[{:>2}] {:.2f}Kb, {}\n'.format(
-                    i, size / 1000, stage.description()))
+                lines.append('[{:>2}] {:.2f}Kb ({:0>5.2f}%), {}\n'.format(
+                    i, size / 1000, 100 * size / total, stage.description()))
             else:
-                lines.append('[{:>2}] {:}b, {}\n'.format(
-                    i, size, stage.description()))
+                lines.append('[{:>2}] {:}b ({:0>5.2f}%), {}\n'.format(
+                    i, size, 100 * size / total, stage.description()))
             lines.append(stage._mem_str())
         return ''.join(lines)
 
@@ -895,7 +916,7 @@ class PdPipeline(PdPipelineStage, collections.abc.Sequence):
             print("Total pipeline size in memory: {:.2f}b".format(
                 size))
         print("Per-stage memory structure:")
-        print(self._mem_str())
+        print(self._mem_str(total=size))
 
     def get_transformer(self):
         """Return the transformer induced by this fitted pipeline.
